aboutsummaryrefslogtreecommitdiff
path: root/test/fixedbugs/issue33460.go
diff options
context:
space:
mode:
Diffstat (limited to 'test/fixedbugs/issue33460.go')
-rw-r--r--test/fixedbugs/issue33460.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/fixedbugs/issue33460.go b/test/fixedbugs/issue33460.go
index 1061d3e746..d90b0a4348 100644
--- a/test/fixedbugs/issue33460.go
+++ b/test/fixedbugs/issue33460.go
@@ -18,11 +18,11 @@ const iii int = 0x3
func f(v int) {
switch v {
case zero, one:
- case two, one: // ERROR "previous case at LINE-1"
+ case two, one: // ERROR "previous case at LINE-1|duplicate case in switch"
case three:
- case 3: // ERROR "previous case at LINE-1"
- case iii: // ERROR "previous case at LINE-2"
+ case 3: // ERROR "previous case at LINE-1|duplicate case in switch"
+ case iii: // ERROR "previous case at LINE-2|duplicate case in switch"
}
}
@@ -31,7 +31,7 @@ const b = "b"
var _ = map[string]int{
"a": 0,
b: 1,
- "a": 2, // ERROR "previous key at LINE-2"
- "b": 3, // ERROR "previous key at LINE-2"
- "b": 4, // ERROR "previous key at LINE-3"
+ "a": 2, // ERROR "previous key at LINE-2|duplicate key in map literal"
+ "b": 3, // GC_ERROR "previous key at LINE-2"
+ "b": 4, // GC_ERROR "previous key at LINE-3"
}